@@ -5,8 +5,8 @@ use base 'PDF::Builder::Resource';
 use strict;
 no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '3.010'; # VERSION
-my $LAST_UPDATE = '3.008'; # manually update whenever code is changed
+our $VERSION = '3.011'; # VERSION
+my $LAST_UPDATE = '3.011'; # manually update whenever code is changed
 
 use Compress::Zlib;
 use Encode qw(:all);
@@ -796,20 +796,20 @@ sub textByStrKern {
 }
 
 sub text {
-    my ($self, $text, $size, $ident) = @_;
+    my ($self, $text, $size, $indent) = @_;
 
     my $newtext = $self->textByStr($text);
 
     if      (defined $size && $self->{'-dokern'}) {
         $newtext = $self->textByStrKern($text);
-        if (defined($ident) && $ident!=0) {
-	    return("[ $ident $newtext ] TJ");
+        if (defined($indent) && $indent!=0) {
+	    return("[ $indent $newtext ] TJ");
         } else {
 	    return("[ $newtext ] TJ");
         }
     } elsif (defined $size) {
-        if (defined($ident) && $ident!=0) {
-	    return("[ $ident ($newtext) ] TJ");
+        if (defined($indent) && $indent!=0) {
+	    return("[ $indent ($newtext) ] TJ");
         } else {
 	    return("[ ($newtext) ] TJ");
         }
